# Projet de développement logiciel - 4BIM INSA Lyon

CriminAI est un logiciel destiné à générer un portrait robot afin de simplifier la tâche de reconnaissance en cas d'aggression.
Le fonctionnement du logiciel repose sur la génération d'images par le logiciel au travers d'un algorithme d'intelligence artificielle, l'autoencodeur variationnel.
Le principe est que la victime puisse faire une sélection des portraits les plus ressemblants à partir d'images générées par IA de manière successive dans le but de s'approcher le plus possible du visage de l'aggresseur. La méthode de génération d'images à partir de la sélection de l'utilisateur est proche d'un algorithme génétique : on applique un bruit sur les différentes caractéristiques de l'image afin de générer de nouvelles images qui sont plus proches de l'ancienne.
